@@ -192,7 +192,7 @@ class LoaderBase(with_metaclass(ABCMeta, object)):
         params['page'] = page
 
         drf_response = server.get(self._path, params, timeout=self.timeout)
-        if drf_response.status_code == http_client.OK:
+        if drf_response and drf_response.status_code == http_client.OK:
             result = drf_response.json()
         else:
             result = None
@@ -616,7 +616,7 @@ def get_address_object(obj_id, timeout=None):
     if obj_id:
         response = server.get('/addrobj/{}/'.format(obj_id), timeout=timeout)
 
-        if response.status_code == http_client.OK:
+        if response and response.status_code == http_client.OK:
             response_data = response.json()
             mapped_data = map_object_data(AddressObjectMapper, response_data)
             result = AddressObject(**mapped_data)
@@ -661,7 +661,7 @@ def get_house(house_id, timeout=None):
 
     response = server.get('/houses/{}/'.format(house_id), timeout=timeout)
 
-    if response.status_code == http_client.OK:
+    if response and response.status_code == http_client.OK:
         response_data = response.json()
         mapped_data = map_object_data(HouseMapper, response_data)
         result = House(**mapped_data)
